@@ -1,18 +1,27 @@
 #!/bin/sh
-
-OSX_VERSION="10.6"
-SDKROOT=`xcode-select -print-path`/Platforms/MacOSX.platform/Developer/SDKs/MacOSX$OSX_VERSION.sdk
-
 set -e
 
+info()
+{
+    local green="\033[1;32m"
+    local normal="\033[0m"
+    echo "[${green}build${normal}] $1"
+}
+
+OSX_VERSION="10.8"
+ARCH="x86_64"
+MINIMAL_OSX_VERSION="10.6"
+SDKROOT=`xcode-select -print-path`/Platforms/MacOSX.platform/Developer/SDKs/MacOSX$OSX_VERSION.sdk
+
 usage()
 {
 cat << EOF
 usage: $0 [-v] [-d]
 
 OPTIONS
-   -v       Be more verbose
-   -d       Enable Debug
+   -v            Be more verbose
+   -k <sdk>      Use the specified sdk (default: $SDKROOT for $ARCH)
+   -a <arch>     Use the specified arch (default: $ARCH)
 EOF
 }
 
@@ -33,7 +42,7 @@ info()
      echo "[${green}info${normal}] $1"
 }
 
-while getopts "hvsdk:" OPTION
+while getopts "hva:k:" OPTION
 do
      case $OPTION in
          h)
@@ -43,7 +52,11 @@ do
          v)
              VERBOSE=yes
              ;;
-         d)  CONFIGURATION="--enable-debug"
+         a)
+             ARCH=$OPTARG
+             ;;
+         k)
+             SDKROOT=$OPTARG
              ;;
          ?)
              usage
@@ -63,6 +76,10 @@ if [ "x$1" != "x" ]; then
     exit 1
 fi
 
+if [ "$ARCH" = "i686" ]; then
+    MINIMAL_OSX_VERSION="10.5"
+fi
+
 export OSX_VERSION
 export SDKROOT
 
@@ -87,6 +104,8 @@ spopd #extras/macosx
 # Build time
 #
 
+export PATH="${npapi_root_dir}/extras/macosx/vlc/extras/tools/build/bin:${npapi_root_dir}/extras/macosx/contrib/${ARCH}-apple-darwin10/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11/bin"
+
 info "Building tools"
 spushd extras/macosx/vlc/extras/tools
 if ! [ -e build ]; then
@@ -98,11 +117,17 @@ info "Fetching contrib"
 
 spushd extras/macosx/vlc/contrib
 
-if ! [ -e 32bit-npapi ]; then
-mkdir 32bit-npapi
-cd 32bit-npapi
-../bootstrap --build=i686-apple-darwin9
-make prebuilt
+if ! [ -e ${ARCH}-npapi ]; then
+mkdir ${ARCH}-npapi
+cd ${ARCH}-npapi
+../bootstrap --build=${ARCH}-apple-darwin10 --disable-disc \
+ --disable-sout --disable-gpl --disable-sdl --disable-sparkle \
+ --disable-bghudappkit --disable-growl --disable-goom \
+ --disable-SDL_image --disable-lua --disable-chromaprint \
+ --disable-caca --disable-upnp --disable-vncserver \
+ --disable-ncurses
+make fetch
+make .gettext && make
 fi
 
 spopd
@@ -110,7 +135,7 @@ spopd
 export CC="xcrun clang"
 export CXX="xcrun clang++"
 export OBJC="xcrun clang"
-PREFIX="${npapi_root_dir}/extras/macosx/vlc/32bit_install_dir"
+PREFIX="${npapi_root_dir}/extras/macosx/vlc/${ARCH}-install"
 
 info "Configuring VLC"
 
@@ -122,29 +147,43 @@ spushd extras/macosx/vlc
 if ! [ -e configure ]; then
     ./bootstrap > ${out}
 fi
-if ! [ -e 32build ]; then
-    mkdir 32build
+if ! [ -e ${ARCH}-build ]; then
+    mkdir ${ARCH}-build
 fi
-cd 32build
+
+CONFIG_OPTIONS=""
+if [ "$ARCH" = "i686" ]; then
+    CONFIG_OPTIONS="--disable-vda"
+    export LDFLAGS="-Wl,-read_only_relocs,suppress"
+fi
+
+cd ${ARCH}-build
 ../configure \
-        --build=i686-apple-darwin9 \
+        --build=${ARCH}-apple-darwin10 \
         --disable-lua --disable-httpd --disable-vlm --disable-sout \
         --disable-vcd --disable-dvdnav --disable-dvdread --disable-screen \
+        --disable-debug \
         --disable-macosx \
-        --enable-merge-ffmpeg \
+        --disable-notify \
+        --disable-projectm \
         --disable-growl \
-        --enable-faad \
+        --disable-faad \
+        --disable-bluray \
         --enable-flac \
         --enable-theora \
         --enable-shout \
-        --enable-ncurses \
-        --enable-twolame \
+        --disable-ncurses \
+        --disable-twolame \
+        --disable-a52 \
         --enable-realrtsp \
         --enable-libass \
         --enable-macosx-audio \
+        --disable-macosx-avfoundation \
+        --disable-macosx-dialog-provider \
         --disable-macosx-eyetv \
         --disable-macosx-qtkit \
-        --disable-macosx-avfoundation \
+        --disable-macosx-quartztext \
+        --disable-macosx-vlc-app \
         --enable-macosx-vout \
         --disable-skins2 \
         --disable-xcb \
@@ -153,13 +192,14 @@ cd 32build
         --disable-samplerate \
         --disable-upnp \
         --disable-goom \
-        --disable-macosx-dialog-provider \
         --disable-nls \
+        --disable-mad \
         --disable-sdl \
         --disable-sdl-image \
-        --disable-macosx-vlc-app \
+        --enable-coregraphicslayer-vout \
         --with-macosx-sdk=$SDKROOT \
-        --with-macosx-version-min=10.5 \
+        --with-macosx-version-min=${MINIMAL_OSX_VERSION} \
+        ${CONFIG_OPTIONS} \
         --prefix=${PREFIX} > ${out}
 
 info "Compiling VLC"
@@ -244,7 +284,6 @@ colorthres
 antiflicker
 anaglyph
 remap
-bluray
 "
 
 for i in ${blacklist}
