@@ -147,11 +147,11 @@ void VlcPluginMac::toggle_fullscreen()
     libvlc_toggle_fullscreen(getMD());
     this->update_controls();
 
-    if (get_fullscreen() == 0) {
+    if (get_fullscreen() != 0) {
         if (!fullscreenWindow) {
             /* this window is kind of useless. however, we need to support 10.5, since enterFullScreenMode depends on the
              * existance of a parent window. This is solved in 10.6 and we should remove the window once we require it. */
-            fullscreenWindow = [[VLCFullscreenWindow alloc] initWithContentRect: NSMakeRect(npwindow.x, npwindow.y, npwindow.width, npwindow.height)];
+            fullscreenWindow = [[VLCFullscreenWindow alloc] initWithContentRect: NSMakeRect(0., 0., npwindow.width, npwindow.height)];
             [fullscreenWindow setLevel: CGShieldingWindowLevel()];
             fullscreenView = [fullscreenWindow customContentView];
 
@@ -174,7 +174,6 @@ void VlcPluginMac::toggle_fullscreen()
         [[fullscreenWindow contentView] enterFullScreenMode: [NSScreen mainScreen] withOptions: [NSDictionary dictionaryWithObjectsAndKeys: [NSNumber numberWithInt: 0], NSFullScreenModeAllScreens, nil]];
     } else {
         [[fullscreenWindow contentView] exitFullScreenModeWithOptions: nil];
-        [fullscreenWindow orderOut: nil];
         [noMediaLayer removeFromSuperlayer];
         [playbackLayer removeFromSuperlayer];
         [controllerLayer removeFromSuperlayer];
@@ -182,6 +181,7 @@ void VlcPluginMac::toggle_fullscreen()
         [browserRootLayer addSublayer: noMediaLayer];
         [browserRootLayer addSublayer: playbackLayer];
         [browserRootLayer addSublayer: controllerLayer];
+        [fullscreenWindow orderOut: nil];
     }
 }
 
@@ -405,8 +405,10 @@ bool VlcPluginMac::handle_event(void *event)
     [aLayer removeFromSuperlayer];
     [CATransaction commit];
 
-    if (playbackLayer == aLayer)
+    if (playbackLayer == aLayer) {
         [playbackLayer release];
+        playbackLayer = nil;
+    }
 }
 
 - (CGSize)currentOutputSize
@@ -490,6 +492,19 @@ bool VlcPluginMac::handle_event(void *event)
     CTLineDraw(textLine, cgContext);
     CFRelease(textLine);
     CFRelease(attRef);
+
+    // expose arch
+#ifdef __x86_64__
+    attRef = CFAttributedStringCreate(kCFAllocatorDefault, CFSTR("Intel, 64-bit"), stylesDict);
+#else
+    attRef = CFAttributedStringCreate(kCFAllocatorDefault, CFSTR("Intel, 32-bit"), stylesDict);
+#endif
+    textLine = CTLineCreateWithAttributedString(attRef);
+    textRect = CTLineGetImageBounds(textLine, cgContext);
+    CGContextSetTextPosition(cgContext, ((windowWidth - textRect.size.width) / 2), ((windowHeight - textRect.size.height) / 2) - 65.);
+    CTLineDraw(textLine, cgContext);
+    CFRelease(textLine);
+    CFRelease(attRef);
     CFRelease(stylesDict);
 #else
     // draw a black rect
@@ -547,7 +562,7 @@ bool VlcPluginMac::handle_event(void *event)
 
 static CGImageRef createImageNamed(NSString *name)
 {
-    CFURLRef url = CFBundleCopyResourceURL(CFBundleGetBundleWithIdentifier(CFSTR("com.netscape.vlc")), (CFStringRef)name, CFSTR("png"), NULL);
+    CFURLRef url = CFBundleCopyResourceURL(CFBundleGetBundleWithIdentifier(CFSTR("org.videolan.vlc-npapi-plugin")), (CFStringRef)name, CFSTR("png"), NULL);
 
     if (!url)
         return NULL;
@@ -676,10 +691,10 @@ static CGImageRef createImageNamed(NSString *name)
     CGContextSaveGState(cgContext);
     CGContextSetFillColorWithColor(cgContext, CGColorGetConstantColor(kCGColorBlack));
     CGContextFillRect(cgContext, self.bounds);
-    CGContextRestoreGState(cgContext);
 
     [self _drawPlayPauseButtonInContext:cgContext];
     [self _drawSliderInContext:cgContext];
+    CGContextRestoreGState(cgContext);
 }
 
 #pragma mark -
