@@ -104,6 +104,19 @@ void VlcWindowlessMac::drawNoPlayback(CGContextRef cgContext)
     CTLineDraw(textLine, cgContext);
     CFRelease(textLine);
     CFRelease(attRef);
+
+    // expose arch
+#ifdef __x86_64__
+    attRef = CFAttributedStringCreate(kCFAllocatorDefault, CFSTR("Intel, 64-bit"), stylesDict);
+#else
+    attRef = CFAttributedStringCreate(kCFAllocatorDefault, CFSTR("Intel, 32-bit"), stylesDict);
+#endif
+    textLine = CTLineCreateWithAttributedString(attRef);
+    textRect = CTLineGetImageBounds(textLine, cgContext);
+    CGContextSetTextPosition(cgContext, ((windowWidth - textRect.size.width) / 2), ((windowHeight - textRect.size.height) / 2) - 65.);
+    CTLineDraw(textLine, cgContext);
+    CFRelease(textLine);
+    CFRelease(attRef);
     CFRelease(stylesDict);
 #else
     // draw a black rect
@@ -207,6 +220,7 @@ bool VlcWindowlessMac::handle_event(void *event)
                                       kCGRenderingIntentPerceptual);
 
             CGDataProviderRelease(dataProvider);
+            CFRelease(dataRef);
 
             if (!lastFrame) {
                 fprintf(stderr, "image creation failed\n");
@@ -223,7 +237,10 @@ bool VlcWindowlessMac::handle_event(void *event)
             rect = CGRectMake(left, top, cached_width, cached_width);
         }
 
-        CGContextDrawImage(cgContext, rect, lastFrame);
+        if(lastFrame) {
+            CGContextDrawImage(cgContext, rect, lastFrame);
+            CGImageRelease(lastFrame);
+        }
 
         CGContextRestoreGState(cgContext);
 
